@@ -25,6 +25,7 @@ __all__ = (
     "SortOrderTypeType",
     "StatusTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -304,10 +305,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -315,3 +318,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_secrets"]
