@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -111,8 +111,8 @@ _OptionalCreateSecretRequestRequestTypeDef = TypedDict(
         "KmsKeyId": str,
         "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
         "SecretString": str,
-        "Tags": List["TagTypeDef"],
-        "AddReplicaRegions": List["ReplicaRegionTypeTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
+        "AddReplicaRegions": Sequence["ReplicaRegionTypeTypeDef"],
         "ForceOverwriteReplicaSecret": bool,
     },
     total=False,
@@ -219,7 +219,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Key": FilterNameStringTypeType,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
     total=False,
 )
@@ -340,7 +340,7 @@ ListSecretsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "SortOrder": SortOrderTypeType,
     },
     total=False,
@@ -408,7 +408,7 @@ _OptionalPutSecretValueRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
         "SecretString": str,
-        "VersionStages": List[str],
+        "VersionStages": Sequence[str],
     },
     total=False,
 )
@@ -435,7 +435,7 @@ RemoveRegionsFromReplicationRequestRequestTypeDef = TypedDict(
     "RemoveRegionsFromReplicationRequestRequestTypeDef",
     {
         "SecretId": str,
-        "RemoveReplicaRegions": List[str],
+        "RemoveReplicaRegions": Sequence[str],
     },
 )
 
@@ -461,7 +461,7 @@ _RequiredReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
     "_RequiredReplicateSecretToRegionsRequestRequestTypeDef",
     {
         "SecretId": str,
-        "AddReplicaRegions": List["ReplicaRegionTypeTypeDef"],
+        "AddReplicaRegions": Sequence["ReplicaRegionTypeTypeDef"],
     },
 )
 _OptionalReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
@@ -623,7 +623,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "SecretId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -640,7 +640,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "SecretId": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
